/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */
package fr.ill.ics.mail;

import fr.ill.ics.bridge.LoginManager;
import fr.ill.ics.bridge.command.CommandZoneWrapper;
import fr.ill.ics.cameo.Application;
import fr.ill.ics.nscclient.serverconnection.ServerConnection;
import fr.ill.ics.nscclient.serverconnection.ServerInstance;
import fr.ill.ics.nscclient.sessionmanagement.SessionManager;
import fr.ill.ics.util.ConfigManager;
import fr.ill.ics.util.exception.ExitException;

public class MailSender {

	private String mailContent;
	
	public static void main(String[] args) {
		int exitCode = 0;
		try {
			MailSender sender = new MailSender();
			sender.init(args);
			sender.run();
		} catch (ExitException e) {
			System.out.println("Exit exception");
			exitCode = e.getExitCode();
		} catch (Throwable e) {
			System.out.println("Unexpected exception");
			e.printStackTrace();

		} finally {
			ServerConnection.getInstance(CommandZoneWrapper.SERVER_ID).reset();
			System.out.println("Resetting Cameo application");
			CommandZoneWrapper.getInstance(CommandZoneWrapper.SERVER_ID).release();
			LoginManager.getInstance().logout(CommandZoneWrapper.SERVER_ID);
			System.out.println("Terminating Cameo application");
			Application.This.terminate();
			System.out.println("Terminated Cameo application");
		}	
		System.out.println("Exiting with code " + exitCode);
		// Get out with exit code.
		System.exit(exitCode);
	}


	private void init(String[] args) {
		
		if (args != null && args.length < 1) {
			System.err.println("Wrong number of arguments, usage is: nomadmail <mail content>");
			System.exit(1);
		}
				
		boolean serverOk = connectToNomadServer();
		if (!serverOk) {
			System.exit(1);
		}
		
		try {
			LoginManager.getInstance().login("mail", true, CommandZoneWrapper.SERVER_ID);
		} catch (Exception e) {
			System.err.println("Error in login");
			e.printStackTrace();
			System.exit(1);
		}
		
		mailContent = args[0];
	}

	private void run() {
		
		System.out.println("Sending " + mailContent);
		
		SessionManager.getInstance(CommandZoneWrapper.SERVER_ID).sendCrashMail(mailContent);
	}

	private boolean connectToNomadServer() {

		ConfigManager.initInstance(null);
		String[] cameoArgs = {ConfigManager.getInstance().getServerEndpoint() + ":nomadmail"};
		Application.This.init(cameoArgs);
		ServerInstance.getInstance().init();

		return true;
	}

}
